@@ -248,9 +248,12 @@ async fn clean_except(
         }
         deno_graph::Module::Npm(npm_module) => {
           if let Some(managed) = npm_resolver.as_managed() {
+            // TODO(dsherret): ok to use for now, but we should use the req in the future
+            #[allow(deprecated)]
+            let nv = npm_module.nv_reference.nv();
             let id = managed
               .resolution()
-              .resolve_pkg_id_from_deno_module(npm_module.nv_reference.nv())
+              .resolve_pkg_id_from_deno_module(nv)
               .unwrap();
             npm_reqs
               .extend(managed.resolution().resolve_pkg_reqs_from_pkg_id(&id));
