@@ -18,3 +18,9 @@ pub mod workspace;
 
 #[cfg(feature = "deno_json")]
 pub use deno_path_util::UrlToFilePathError;
+#[cfg(feature = "deno_json")]
+pub use util::ParseDateOrDurationError;
+#[cfg(feature = "deno_json")]
+pub use util::ParseIso8601DurationError;
+#[cfg(feature = "deno_json")]
+pub use util::parse_minutes_duration_or_date;
