@@ -11,6 +11,8 @@ use deno_cache_dir::GlobalHttpCacheRc;
 use deno_cache_dir::GlobalOrLocalHttpCache;
 use deno_cache_dir::LocalHttpCache;
 use deno_cache_dir::npm::NpmCacheDir;
+use deno_config::deno_json::MinimumDependencyAgeConfig;
+use deno_config::deno_json::NewestDependencyDate;
 use deno_config::deno_json::NodeModulesDirMode;
 use deno_config::workspace::FolderConfigs;
 use deno_config::workspace::VendorEnablement;
@@ -229,6 +231,7 @@ pub trait WorkspaceFactorySys:
   + deno_cache_dir::GlobalHttpCacheSys
   + deno_cache_dir::LocalHttpCacheSys
   + crate::loader::NpmModuleLoaderSys
+  + sys_traits::SystemTimeNow
 {
 }
 
@@ -660,7 +663,7 @@ pub struct ResolverFactoryOptions {
   pub compiler_options_overrides: CompilerOptionsOverrides,
   pub is_cjs_resolution_mode: IsCjsResolutionMode,
   /// Prevents installing packages newer than the specified date.
-  pub newest_dependency_date: Option<chrono::DateTime<chrono::Utc>>,
+  pub newest_dependency_date: Option<NewestDependencyDate>,
   pub node_analysis_cache: Option<NodeAnalysisCacheRc>,
   pub node_code_translator_mode: node_resolver::analyze::NodeCodeTranslatorMode,
   pub node_resolver_options: NodeResolverOptions,
@@ -697,6 +700,7 @@ pub struct ResolverFactory<TSys: WorkspaceFactorySys> {
   in_npm_package_checker: Deferred<DenoInNpmPackageChecker>,
   #[cfg(feature = "graph")]
   jsr_version_resolver: Deferred<JsrVersionResolverRc>,
+  minimum_dependency_age: Deferred<MinimumDependencyAgeConfig>,
   node_code_translator: Deferred<DenoNodeCodeTranslatorRc<TSys>>,
   node_resolver: Deferred<
     NodeResolverRc<
@@ -733,9 +737,6 @@ impl<TSys: WorkspaceFactorySys> ResolverFactory<TSys> {
     workspace_factory: WorkspaceFactoryRc<TSys>,
     options: ResolverFactoryOptions,
   ) -> Self {
-    if let Some(newest_dependency_date) = options.newest_dependency_date {
-      log::debug!("Newest dependency date: {}", newest_dependency_date);
-    }
     Self {
       sys: NodeResolutionSys::new(
         workspace_factory.sys.clone(),
@@ -754,6 +755,7 @@ impl<TSys: WorkspaceFactorySys> ResolverFactory<TSys> {
       in_npm_package_checker: Default::default(),
       #[cfg(feature = "graph")]
       jsr_version_resolver: Default::default(),
+      minimum_dependency_age: Default::default(),
       node_code_translator: Default::default(),
       node_resolver: Default::default(),
       npm_module_loader: Default::default(),
@@ -932,12 +934,51 @@ impl<TSys: WorkspaceFactorySys> ResolverFactory<TSys> {
     &self,
   ) -> Result<&JsrVersionResolverRc, anyhow::Error> {
     self.jsr_version_resolver.get_or_try_init(|| {
+      let minimum_dependency_age_config =
+        self.minimum_dependency_age_config()?;
       Ok(new_rc(deno_graph::packages::JsrVersionResolver {
-        newest_dependency_date: self.options.newest_dependency_date,
+        newest_dependency_date_options:
+          deno_graph::packages::NewestDependencyDateOptions {
+            date: minimum_dependency_age_config
+              .age
+              .as_ref()
+              .and_then(|d| d.into_option())
+              .map(deno_graph::packages::NewestDependencyDate),
+            exclude_jsr_pkgs: minimum_dependency_age_config
+              .exclude
+              .iter()
+              .filter_map(|v| v.strip_prefix("jsr:"))
+              .map(|v| v.into())
+              .collect(),
+          },
       }))
     })
   }
 
+  /// The newest allowed dependency date.
+  pub fn minimum_dependency_age_config(
+    &self,
+  ) -> Result<&MinimumDependencyAgeConfig, anyhow::Error> {
+    self.minimum_dependency_age.get_or_try_init(|| {
+      let config = if let Some(date) = self.options.newest_dependency_date {
+        MinimumDependencyAgeConfig {
+          age: Some(date),
+          exclude: Vec::new(),
+        }
+      } else {
+        let workspace_factory = self.workspace_factory();
+        let workspace = &workspace_factory.workspace_directory()?.workspace;
+        workspace.minimum_dependency_age(workspace_factory.sys())?
+      };
+      if let Some(newest_dependency_date) =
+        config.age.and_then(|d| d.into_option())
+      {
+        log::debug!("Newest dependency date: {}", newest_dependency_date);
+      }
+      Ok(config)
+    })
+  }
+
   pub fn node_code_translator(
     &self,
   ) -> Result<&DenoNodeCodeTranslatorRc<TSys>, anyhow::Error> {
@@ -1048,9 +1089,24 @@ impl<TSys: WorkspaceFactorySys> ResolverFactory<TSys> {
     &self,
   ) -> Result<&NpmVersionResolverRc, anyhow::Error> {
     self.npm_version_resolver.get_or_try_init(|| {
+      let minimum_dependency_age_config =
+        self.minimum_dependency_age_config()?;
       Ok(new_rc(NpmVersionResolver {
         types_node_version_req: self.options.types_node_version_req.clone(),
-        newest_dependency_date: self.options.newest_dependency_date,
+        newest_dependency_date_options:
+          deno_npm::resolution::NewestDependencyDateOptions {
+            date: minimum_dependency_age_config
+              .age
+              .as_ref()
+              .and_then(|d| d.into_option())
+              .map(deno_npm::resolution::NewestDependencyDate),
+            exclude: minimum_dependency_age_config
+              .exclude
+              .iter()
+              .filter_map(|v| v.strip_prefix("npm:"))
+              .map(|v| v.into())
+              .collect(),
+          },
         link_packages: self
           .workspace_factory
           .workspace_npm_link_packages()?
