@@ -1737,19 +1737,6 @@ fn pkg_json_to_version_info(
           .collect()
       })
       .unwrap_or_default(),
-    directories: pkg_json
-      .directories
-      .as_ref()
-      .map(|directories| {
-        directories
-          .iter()
-          .filter_map(|(k, v)| {
-            let v = v.as_str()?;
-            Some((SmallStackString::from_str(k), v.to_string()))
-          })
-          .collect()
-      })
-      .unwrap_or_default(),
     // not worth increasing memory for showing a deprecated
     // message for linked packages
     deprecated: None,
@@ -3216,9 +3203,6 @@ mod test {
   "bundleDependencies": [
     "my-dep"
   ],
-  "directories": {
-    "bin": "./bin"
-  },
   "peerDependenciesMeta": {
     "my-peer-dep": {
       "optional": true
@@ -3260,10 +3244,6 @@ mod test {
         )]),
         os: vec![SmallStackString::from_static("win32")],
         cpu: vec![SmallStackString::from_static("x86_64")],
-        directories: HashMap::from([(
-          SmallStackString::from_static("bin"),
-          "./bin".to_string(),
-        ),]),
         scripts: HashMap::from([
           (
             SmallStackString::from_static("script"),
